# Copyright (c) 2017 VMware, Inc. All Rights Reserved.
# SPDX-License-Identifier: BSD-2-Clause

import ConfigParser
import os

from ansible import cli
from ansible import constants
from ansible.parsing import dataloader
from ansible.parsing import vault
from ansible.utils import display


ANSIBLE_CFG = os.path.join(os.sep, 'etc', 'ansible', 'ansible.cfg')
VAULT_PWD_FILE = os.path.join(os.sep, 'etc', 'column', 'vault_pass.txt')
DEFAULTS = {
    'vault_password_file': VAULT_PWD_FILE
}


def _get_vault_password_file():
    if os.path.exists(ANSIBLE_CFG):
        cfg = ConfigParser.ConfigParser(DEFAULTS)
        cfg.read(ANSIBLE_CFG)
        return cfg.get('defaults', 'vault_password_file')


def reload_log_path(log_path):
    os.environ['ANSIBLE_LOG_PATH'] = log_path
    reload(constants)
    reload(display)


def vault_decrypt(value):
    vault_password = cli.CLI.read_vault_password_file(
        _get_vault_password_file(), dataloader.DataLoader())
    this_vault = vault.VaultLib(vault_password)
    return this_vault.decrypt(value)


def vault_encrypt(value):
    vault_password = cli.CLI.read_vault_password_file(
        _get_vault_password_file(), dataloader.DataLoader())
    this_vault = vault.VaultLib(vault_password)
    return this_vault.encrypt(value)
